@@ -14,7 +14,7 @@
 var currentLevel;
 var numberOfLevel;
 var items;
-var url = "qrc:/gcompris/src/activities/align4-2players/resource/";
+var url = "qrc:/gcompris/src/activities/align4_2players/resource/";
 var currentPiece;
 var currentPlayer;
 var currentLocation;
