@@ -15,163 +15,163 @@
 
 var fishes = [
             {
-              "imgName": "blueking2.png",
+              "imgName": "blueking2.webp",
               "nbFrame": 2,
               "width": 118,
               "height": 76
             },
             {
-              "imgName": "butfish.png",
+              "imgName": "butfish.webp",
               "nbFrame": 2,
               "width": 98,
               "height": 82
             },
             {
-              "imgName": "cichlid1.png",
+              "imgName": "cichlid1.webp",
               "nbFrame": 2,
               "width": 63,
               "height": 37
             },
             {
-              "imgName": "cichlid4.png",
+              "imgName": "cichlid4.webp",
               "nbFrame": 2,
               "width": 73,
               "height": 44
             },
             {
-              "imgName": "collaris.png",
+              "imgName": "collaris.webp",
               "nbFrame": 2,
               "width": 62,
               "height": 50
             },
             {
-              "imgName": "discus2.png",
+              "imgName": "discus2.webp",
               "nbFrame": 2,
               "width": 100,
               "height": 100
             },
             {
-              "imgName": "discus3.png",
+              "imgName": "discus3.webp",
               "nbFrame": 2,
               "width": 63,
               "height": 57
             },
             {
-              "imgName": "f00.png",
+              "imgName": "f00.webp",
               "nbFrame": 2,
               "width": 64,
               "height": 59
             },
             {
-              "imgName": "f01.png",
+              "imgName": "f01.webp",
               "nbFrame": 2,
               "width": 63,
               "height": 50
             },
             {
-              "imgName": "f02.png",
+              "imgName": "f02.webp",
               "nbFrame": 2,
               "width": 71,
               "height": 44
             },
             {
-              "imgName": "f03.png",
+              "imgName": "f03.webp",
               "nbFrame": 2,
               "width": 83,
               "height": 52
             },
             {
-              "imgName": "f04.png",
+              "imgName": "f04.webp",
               "nbFrame": 2,
               "width": 93,
               "height": 62
             },
             {
-              "imgName": "f05.png",
+              "imgName": "f05.webp",
               "nbFrame": 2,
               "width": 90,
               "height": 49
             },
             {
-              "imgName": "f06.png",
+              "imgName": "f06.webp",
               "nbFrame": 2,
               "width": 93,
               "height": 44
             },
             {
-              "imgName": "f07.png",
+              "imgName": "f07.webp",
               "nbFrame": 2,
               "width": 82,
               "height": 75
             },
             {
-              "imgName": "f08.png",
+              "imgName": "f08.webp",
               "nbFrame": 2,
               "width": 91,
               "height": 70
             },
             {
-              "imgName": "f09.png",
+              "imgName": "f09.webp",
               "nbFrame": 2,
               "width": 108,
               "height": 86
             },
             {
-              "imgName": "f10.png",
+              "imgName": "f10.webp",
               "nbFrame": 2,
               "width": 97,
               "height": 60
             },
             {
-              "imgName": "f11.png",
+              "imgName": "f11.webp",
               "nbFrame": 2,
               "width": 116,
               "height": 42
             },
             {
-              "imgName": "f12.png",
+              "imgName": "f12.webp",
               "nbFrame": 2,
               "width": 100,
               "height": 35
             },
             {
-              "imgName": "f13.png",
+              "imgName": "f13.webp",
               "nbFrame": 2,
               "width": 116,
               "height": 73
             },
             {
-              "imgName": "manta.png",
+              "imgName": "manta.webp",
               "nbFrame": 2,
               "width": 266,
               "height": 91
             },
             {
-              "imgName": "newf1.png",
+              "imgName": "newf1.webp",
               "nbFrame": 2,
               "width": 118,
               "height": 81
             },
             {
-              "imgName": "QueenAngel.png",
+              "imgName": "QueenAngel.webp",
               "nbFrame": 2,
               "width": 78,
               "height": 54
             },
             {
-              "imgName": "shark1.png",
+              "imgName": "shark1.webp",
               "nbFrame": 2,
               "width": 187,
               "height": 53
             },
             {
-              "imgName": "six_barred.png",
+              "imgName": "six_barred.webp",
               "nbFrame": 2,
               "width": 76,
               "height": 63
             },
             {
-              "imgName": "teeth.png",
+              "imgName": "teeth.webp",
               "nbFrame": 8,
               "width": 64,
               "height": 64
@@ -242,7 +242,7 @@ function initLevel() {
     destroyFishes();
     bar.level = currentLevel + 1
     background.source = "qrc:/gcompris/src/activities/clickgame/resource/sea" +
-            bar.level + ".jpg"
+            bar.level + ".webp"
     var nbFish = levelProperty[currentLevel].nbFish
     createdFishes = new Array(nbFish)
     for(var i = 0;  i < nbFish; ++i) {
