@@ -137,7 +137,7 @@ function createPlanet() {
         } else if(planetSide == 1) {
             currentPlanet = items.planet1;
         }
-        currentPlanet.source = url + "planet" + Math.floor(Math.random() * 2) + ".png";
+        currentPlanet.source = url + "planet" + Math.floor(Math.random() * 2) + ".webp";
         currentPlanet.fallDuration = levels[currentLevel].planetFrequency;
         currentPlanet.height = planetSize;
         currentPlanet.width = planetSize;
