@@ -107,6 +107,9 @@ function initLevel() {
     max = items.onScreenControls ? items.background.width - items.upDownControl.width - items.landing.width : max;
     items.landing.anchors.leftMargin = Math.random() * (max- min) + min;
     items.landing.overlayColor = "-g";
+    items.leftEngine.reset();
+    items.rightEngine.reset();
+    items.bottomEngine.reset();
 
     // initialize world:
     items.world.pixelsPerMeter = pxYToAltitude(items.rocket.y) / startingAltitudeReal;
@@ -174,6 +177,10 @@ function processKeyPress(event)
         else
             return;
     }
+
+    if(items.bonus.isPlaying) {
+        return;
+    }
     var newAccel = 0;
     if(key === Qt.Key_Up || key === Qt.Key_Down) {
         if (key === Qt.Key_Up) {
@@ -216,6 +223,11 @@ function processKeyRelease(event)
         event.accepted = false;
         return;
     }
+    if(items.bonus.isPlaying) {
+        event.accepted = false;
+        return;
+    }
+
     var key = event.key;
     event.accepted = true;
     //console.log("XXX release " + key + " = " + event.isAutoRepeat + " = " + Qt.Key_Right);
@@ -230,12 +242,15 @@ function processKeyRelease(event)
 function finishLevel(success)
 {
     items.rocket.accel = 0;
-    items.rocket.leftAccel = 0;
-    items.rocket.rightAccel = 0;
-    items.rocket.body.linearVelocity = Qt.point(0,0)
-    if (success)
+    if (success) {
+        items.rocket.leftAccel = 0;
+        items.rocket.rightAccel = 0;
+        items.rocket.body.linearVelocity = Qt.point(0,0)
+
         items.bonus.good("lion");
-    else {
+    } else {
+        // don't reset physics on a crash so the explosion rolls along landscape.
+
         items.explosion.show();
         items.rocket.hide();
         items.bonus.bad("lion");
