@@ -1,26 +1,15 @@
 /* GCompris - photo_hunter.js
  *
- * Copyright (C) 2016 Stefan Toncu <stefan.toncu29@gmail.com>
+ * SPDX-FileCopyrightText: 2016 Stefan Toncu <stefan.toncu29@gmail.com>
  *
  * Authors:
  *   <Marc Le Douarain> (GTK+ version)
  *   Stefan Toncu <stefan.toncu29@gmail.com> (Qt Quick port)
  *
- *   This program is free software; you can redistribute it and/or modify
- *   it under the terms of the GNU General Public License as published by
- *   the Free Software Foundation; either version 3 of the License, or
- *   (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, see <https://www.gnu.org/licenses/>.
+ *   SPDX-License-Identifier: GPL-3.0-or-later
  */
 .pragma library
-.import QtQuick 2.6 as Quick
+.import QtQuick 2.9 as Quick
 
 var currentLevel = 0
 var items
@@ -103,6 +92,8 @@ function initLevel() {
     items.bar.level = currentLevel + 1
     items.background.startedHelp = false
 
+    items.problem.hideProblem = !items.showProblem
+
     setUp()
 }
 
@@ -162,12 +153,6 @@ function photoClicked(item, index) {
     }
 }
 
-function hideProblem() {
-    items.frame.anchors.top = items.background.top
-    items.frame.problemTextHeight = 0
-    items.problem.z = -5
-}
-
 function nextLevel() {
     if(numberOfLevel <= ++currentLevel) {
         currentLevel = 0
