@@ -115,6 +115,11 @@ ApplicationSettings::ApplicationSettings(const QString &configPath, QObject *par
 
     m_sectionVisible = m_config.value(SECTION_VISIBLE, true).toBool();
     m_wordset = m_config.value(WORDSET, "").toString();
+
+    // Automatically override the previous rcc with the new one
+    if (m_wordset == QLatin1String("data2/words/words.rcc"))
+        m_wordset = "data2/words/words-webp.rcc";
+
     m_useWordset = m_config.value(USE_WORDSET, true).toBool();
     m_isAutomaticDownloadsEnabled = m_config.value(ENABLE_AUTOMATIC_DOWNLOADS,
                                                    !ApplicationInfo::getInstance()->isMobile() && ApplicationInfo::isDownloadAllowed())
@@ -363,8 +368,8 @@ void ApplicationSettings::notifySectionVisibleChanged()
 
 void ApplicationSettings::notifyWordsetChanged()
 {
-    if (!m_wordset.isEmpty() && DownloadManager::getInstance()->haveLocalResource(m_wordset) && !DownloadManager::getInstance()->isDataRegistered("words")) {
-        // words.rcc is there -> register old file first
+    if (!m_wordset.isEmpty() && DownloadManager::getInstance()->haveLocalResource(m_wordset) && !DownloadManager::getInstance()->isDataRegistered("words-webp")) {
+        // words-webp.rcc is there -> register old file first
         // then try to update in the background
         DownloadManager::getInstance()->updateResource(m_wordset);
     }
@@ -509,7 +514,7 @@ void ApplicationSettings::saveActivityProgress(const QString &activity, int prog
 
 bool ApplicationSettings::useExternalWordset()
 {
-    return !m_wordset.isEmpty() && DownloadManager::getInstance()->isDataRegistered("words");
+    return !m_wordset.isEmpty() && DownloadManager::getInstance()->isDataRegistered("words-webp");
 }
 
 QObject *ApplicationSettings::applicationSettingsProvider(QQmlEngine *engine,
